@@ -52,7 +52,19 @@ class SalesforceProvider(
         :param username: Salesforce Username of a System Administrator like user for the provider to authenticate as. Can be specified with the environment variable SALESFORCE_USERNAME. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/salesforce#username SalesforceProvider#username}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SalesforceProvider.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                alias: typing.Optional[builtins.str] = None,
+                api_version: typing.Optional[builtins.str] = None,
+                client_id: typing.Optional[builtins.str] = None,
+                login_url: typing.Optional[builtins.str] = None,
+                private_key: typing.Optional[builtins.str] = None,
+                username: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = SalesforceProviderConfig(
@@ -137,7 +149,9 @@ class SalesforceProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SalesforceProvider, "alias").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -149,7 +163,9 @@ class SalesforceProvider(
     @api_version.setter
     def api_version(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SalesforceProvider, "api_version").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "apiVersion", value)
 
@@ -161,7 +177,9 @@ class SalesforceProvider(
     @client_id.setter
     def client_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SalesforceProvider, "client_id").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientId", value)
 
@@ -173,7 +191,9 @@ class SalesforceProvider(
     @login_url.setter
     def login_url(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SalesforceProvider, "login_url").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "loginUrl", value)
 
@@ -185,7 +205,9 @@ class SalesforceProvider(
     @private_key.setter
     def private_key(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SalesforceProvider, "private_key").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "privateKey", value)
 
@@ -197,7 +219,9 @@ class SalesforceProvider(
     @username.setter
     def username(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(SalesforceProvider, "username").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "username", value)
 
@@ -234,7 +258,17 @@ class SalesforceProviderConfig:
         :param username: Salesforce Username of a System Administrator like user for the provider to authenticate as. Can be specified with the environment variable SALESFORCE_USERNAME. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/salesforce#username SalesforceProvider#username}
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SalesforceProviderConfig.__init__)
+            def stub(
+                *,
+                alias: typing.Optional[builtins.str] = None,
+                api_version: typing.Optional[builtins.str] = None,
+                client_id: typing.Optional[builtins.str] = None,
+                login_url: typing.Optional[builtins.str] = None,
+                private_key: typing.Optional[builtins.str] = None,
+                username: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
             check_type(argname="argument api_version", value=api_version, expected_type=type_hints["api_version"])
             check_type(argname="argument client_id", value=client_id, expected_type=type_hints["client_id"])
